@@ -1,8 +1,9 @@
+from F import LIST
 from FCM.Jarticle.jProvider.jDate import jpDate
 from FCM.Jarticle.jProvider.jCategories import jpCat
 from FCM.Jarticle.jProvider.jSocial import jpSocial
 from FCM.Jarticle.jProvider.jSearch import jpSearch
-
+from FCM.Jarticle.jProvider import jSort
 ARTICLES_COLLECTION = "articles"
 
 """
@@ -23,6 +24,13 @@ class jPro(jpSearch, jpDate, jpCat, jpSocial):
         self.constructor_jarticles_with_host(dbUri, dbName)
         print(self.mcollection_name)
 
+    def get_meta_feed(self):
+        search_results = self.search_all("metaverse")
+        cat_results = self.get_metaverse_articles()
+        flattened_list = LIST.flatten(search_results, cat_results)
+        final_results = jSort.sort_articles_by_date(flattened_list)
+        return final_results[:100]
+
     def get_article_count(self):
         return self.get_document_count()
 
